@@ -54,6 +54,14 @@ using namespace IncidenceEditorNG;
 namespace
 {
 static const char myIncidenceDialogConfigGroupName[] = "IncidenceDialog";
+
+IncidenceEditorNG::EditorItemManager::ItipPrivacyFlags toItemManagerFlags(bool sign, bool encrypt)
+{
+    IncidenceEditorNG::EditorItemManager::ItipPrivacyFlags flags;
+    flags.setFlag(IncidenceEditorNG::EditorItemManager::ItipPrivacySign, sign);
+    flags.setFlag(IncidenceEditorNG::EditorItemManager::ItipPrivacyEncrypt, encrypt);
+    return flags;
+}
 }
 namespace IncidenceEditorNG
 {
@@ -77,7 +85,7 @@ public:
     IncidenceResource *mIeResource = nullptr;
     bool mInitiallyDirty = false;
     Akonadi::Item mItem;
-    Q_REQUIRED_RESULT QString typeToString(const int type) const;
+    [[nodiscard]] QString typeToString(const int type) const;
 
 public:
     IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq);
@@ -99,15 +107,15 @@ public:
     void setCalendarCollection(const Akonadi::Collection &collection);
 
     /// ItemEditorUi methods
-    Q_REQUIRED_RESULT bool containsPayloadIdentifiers(const QSet<QByteArray> &partIdentifiers) const override;
+    [[nodiscard]] bool containsPayloadIdentifiers(const QSet<QByteArray> &partIdentifiers) const override;
     void handleItemSaveFinish(EditorItemManager::SaveAction);
     void handleItemSaveFail(EditorItemManager::SaveAction, const QString &errorMessage);
-    Q_REQUIRED_RESULT bool hasSupportedPayload(const Akonadi::Item &item) const override;
-    Q_REQUIRED_RESULT bool isDirty() const override;
-    Q_REQUIRED_RESULT bool isValid() const override;
+    [[nodiscard]] bool hasSupportedPayload(const Akonadi::Item &item) const override;
+    [[nodiscard]] bool isDirty() const override;
+    [[nodiscard]] bool isValid() const override;
     void load(const Akonadi::Item &item) override;
     Akonadi::Item save(const Akonadi::Item &item) override;
-    Q_REQUIRED_RESULT Akonadi::Collection selectedCollection() const override;
+    [[nodiscard]] Akonadi::Collection selectedCollection() const override;
 
     void reject(RejectReason reason, const QString &errorMessage = QString()) override;
 };
@@ -707,7 +715,7 @@ IncidenceDialog::~IncidenceDialog()
 
 void IncidenceDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), myIncidenceDialogConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myIncidenceDialogConfigGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
@@ -715,7 +723,7 @@ void IncidenceDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(500, 500));
-    KConfigGroup group(KSharedConfig::openStateConfig(), myIncidenceDialogConfigGroupName);
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myIncidenceDialogConfigGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
@@ -762,7 +770,7 @@ void IncidenceDialog::slotButtonClicked(QAbstractButton *button)
             d->mUi->buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
             d->mCloseOnSave = true;
             d->mInitiallyDirty = false;
-            d->mItemManager->save();
+            d->mItemManager->save(toItemManagerFlags(d->mUi->mSignItip->isChecked(), d->mUi->mEncryptItip->isChecked()));
         } else {
             close();
         }
@@ -773,7 +781,7 @@ void IncidenceDialog::slotButtonClicked(QAbstractButton *button)
 
         d->mCloseOnSave = false;
         d->mInitiallyDirty = false;
-        d->mItemManager->save();
+        d->mItemManager->save(toItemManagerFlags(d->mUi->mSignItip->isChecked(), d->mUi->mEncryptItip->isChecked()));
     } else if (d->mUi->buttonBox->button(QDialogButtonBox::Cancel) == button) {
         if (d->isDirty()
             && KMessageBox::questionTwoActions(this,
